From: Gabor Juhos <juhosg@openwrt.org>
Date: Sat, 12 Apr 2014 19:58:23 +0000 (+0000)
Subject: ar71xx: wndr4300: indicate WNDR3700v4 in the kernel support files
X-Git-Url: http://git.cdn.openwrt.org/?a=commitdiff_plain;h=4149ab5193d09ffdbaaaeb3c9f041ba212efb31c;p=openwrt%2Fstaging%2Fdangole.git

ar71xx: wndr4300: indicate WNDR3700v4 in the kernel support files

Apart from the wireless chip, the WNDR3700 v4 and the WNDR4300
is the same device. Indicate this in the kernel files.

Signed-off-by: Gabor Juhos <juhosg@openwrt.org>

SVN-Revision: 40479
---

diff --git a/target/linux/ar71xx/patches-3.10/610-MIPS-ath79-openwrt-machines.patch b/target/linux/ar71xx/patches-3.10/610-MIPS-ath79-openwrt-machines.patch
index 52d5794612..f05fc09fd9 100644
--- a/target/linux/ar71xx/patches-3.10/610-MIPS-ath79-openwrt-machines.patch
+++ b/target/linux/ar71xx/patches-3.10/610-MIPS-ath79-openwrt-machines.patch
@@ -125,7 +125,7 @@
 +	ATH79_MACH_WLR8100,		/* SITECOM WLR-8100 */
 +	ATH79_MACH_WNDAP360,		/* NETGEAR WNDAP360 */
 +	ATH79_MACH_WNDR3700,		/* NETGEAR WNDR3700/WNDR3800/WNDRMAC */
-+	ATH79_MACH_WNDR4300,		/* NETGEAR WNDR4300 */
++	ATH79_MACH_WNDR4300,		/* NETGEAR WNDR3700v4/WNDR4300 */
 +	ATH79_MACH_WNR2000,		/* NETGEAR WNR2000 */
 +	ATH79_MACH_WNR2000_V3,		/* NETGEAR WNR2000 v3 */
 +	ATH79_MACH_WNR2200,		/* NETGEAR WNR2200 */
@@ -580,7 +580,7 @@
 +	select ATH79_DEV_USB
 +
 +config ATH79_MACH_WNDR4300
-+	bool "NETGEAR WNDR4300 board support"
++	bool "NETGEAR WNDR3700v4/WNDR4300 board support"
 +	select SOC_AR934X
 +	select ATH79_DEV_AP9X_PCI if PCI
 +	select ATH79_DEV_ETH
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/mach-wndr4300.c b/target/linux/ar71xx/files/arch/mips/ath79/mach-wndr4300.c
index dcdc68ba4f..ae72ab66c4 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/mach-wndr4300.c
+++ b/target/linux/ar71xx/files/arch/mips/ath79/mach-wndr4300.c
@@ -1,5 +1,5 @@
 /*
  *  NETGEAR WNDR4300 board support
  *
  *  Copyright (C) 2012 Gabor Juhos <juhosg@openwrt.org>
  *  Copyright (C) 2014 Ralph Perlich <rpsoft@arcor.de>
@@ -204,5 +204,5 @@ static void __init wndr4300_setup(void)
 	ap91_pci_init_simple();
 }
 
-MIPS_MACHINE(ATH79_MACH_WNDR4300, "WNDR4300", "NETGEAR WNDR4300",
+MIPS_MACHINE(ATH79_MACH_WNDR4300, "WNDR4300", "NETGEAR WNDR3700v4/WNDR4300",
 	     wndr4300_setup);
@@ -1,5 +1,5 @@
 /*
- *  NETGEAR WNDR4300 board support
+ *  NETGEAR WNDR3700v4/WNDR4300 board support
  *
  *  Copyright (C) 2012 Gabor Juhos <juhosg@openwrt.org>